==> benno-web-2.1.6.tgz: srv/benno/bennoweb/htdocs/model/StoredQuery.php <==
<?php
/*
 * Benno MailArchiv
 *
 * Copyright  2008-2012 LWsystems GmbH & Co. KG
 *
 * http://www.lw-systems.de/
 * http://www.benno-mailarchiv.de/
 *
 * All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License version 3
 * as published by the Free Software Foundation.
 *
 * Binary versions of this file provided by LWsystems to you as
 * well as other copyrighted, protected or trademarked materials like
 * logos, graphics, fonts, specific documentations and configurations,
 * cryptographic keys etc. are subject to a license agreement between
 * you and LWsystems.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You can find a copy of the GNU Affero General Public License at
 * this URI:
 * http://www.gnu.org/licenses/agpl-3.0.html
 * If not, write to the Free Software Foundation, Inc., 59 Temple Place,
 * Suite 330, Boston, MA  02111-1307  USA
 */

require_once 'SPAF2/Persistence.php';

class StoredQuery extends Persistence
{

    var $id;
    var $userid;
    var $name;
    var $query;


    function StoredQuery ($id,$userid='',$name='',$Query='')
    {
        $this->id     = $id;
        $this->userid = $userid;
        $this->name   = $name;
        $this->query  = $Query;
    }


    // save objects from storage backend
    function load ()
    {
        parent::load();
        $this->query = unserialize($this->query);
        if (! $this->query) {
            throw new Exception('NO_QUERY');
        }
    }


    // save objects at storage backend
    function save ()
    {
        // check if query with this name exists
        global $App;
        $DB = $App->DB;
        $sql = "SELECT * FROM storedquery WHERE name = '".$this->name."' AND userid = '".$this->userid."'";
        $res = $DB->query($sql);
        if ($row = $res->fetchRow()) {
            throw new Exception('QUERY_NAME_EXISTS');
        }

        // store query
        $QueryObject = $this->query;
        $this->query = serialize($this->query);
        parent::save();
        $this->query = $QueryObject;
    }


    /**
     * FetchList
     *
     * Fetch a list of objects from database
     *
     * @access public
     * @param string $userid
     * @return array entries
     */
    function FetchList ($userid)
    {  

        global $App;
        $entries = array();
        $DB = $App->DB;
        $sql = "SELECT * FROM storedquery WHERE userid = '".$userid."' ORDER BY name";
        $res = $DB->query($sql);
        while ($row = $res->fetchRow()) {
            array_push($entries,new StoredQuery($row['id'],$row['userid'],$row['name'],unserialize($row['query'])));
        }
        return $entries;
    }

}
?>

==> benno-web-2.6.1.tgz: srv/benno/bennoweb/htdocs/model/StoredQuery.php <==
<?php
/*
 * Benno MailArchiv
 *
 * Copyright  2008-2012 LWsystems GmbH & Co. KG
 *
 * http://www.lw-systems.de/
 * http://www.benno-mailarchiv.de/
 *
 * All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License version 3
 * as published by the Free Software Foundation.
 *
 * Binary versions of this file provided by LWsystems to you as
 * well as other copyrighted, protected or trademarked materials like
 * logos, graphics, fonts, specific documentations and configurations,
 * cryptographic keys etc. are subject to a license agreement between
 * you and LWsystems.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You can find a copy of the GNU Affero General Public License at
 * this URI:
 * http://www.gnu.org/licenses/agpl-3.0.html
 * If not, write to the Free Software Foundation, Inc., 59 Temple Place,
 * Suite 330, Boston, MA  02111-1307  USA
 */

require_once 'SPAF2/Persistence.php';
require_once 'model/Query.php';

class StoredQuery extends Persistence
{

    var $id;
    var $userid;
    var $name;
    var $query;


    function StoredQuery ($id,$userid='',$name='',$Query='')
    {
        $this->id     = $id;
        $this->userid = $userid;
        $this->name   = $name;
        $this->query  = $Query;
    }


    // save objects from storage backend
    function load ()
    {
        parent::load();
        $this->query = unserialize($this->query);
        if (! $this->query) {
            throw new Exception('NO_QUERY');
        }
    }


    // save objects at storage backend
    function save ()
    {
        // check if query with this name exists
        global $App;
        $DB = $App->DB;
        $sql = "SELECT * FROM storedquery WHERE name = '".$this->name."' AND userid = '".$this->userid."'";
        $res = $DB->query($sql);
        if ($row = $res->fetchRow()) {
            throw new Exception('QUERY_NAME_EXISTS');
        }

        // store query
        $QueryObject = $this->query;
        $this->query = serialize($this->query);
        parent::save();
        $this->query = $QueryObject;
    }


    /**
     * FetchList
     *
     * Fetch a list of objects from database
     *
     * @access public
     * @param string $userid
     * @return array entries
     */
    public static function FetchList ($userid)
    {  

        global $App;
        $entries = array();
        $DB = $App->DB;
        $sql = "SELECT * FROM storedquery WHERE userid = '".$userid."' ORDER BY name";
        $res = $DB->query($sql);
        while ($row = $res->fetchRow()) {
            array_push($entries,new StoredQuery($row['id'],$row['userid'],$row['name'],unserialize($row['query'])));
        }
        return $entries;
    }


    /**
     * getQuery
     *
     * Returns the query object
     *
     * @access public
     * @return object query
     */
    public function getQuery ()
    {
        $query = $this->query;
        if ($query->type == '') {
            $query->type = 'Ext';
        }

        return $query;
    }


}
?>
